<?php
declare(strict_types=1);

namespace Inti\Media\Handler;

use Laminas\Diactoros\Response;
use League\Flysystem\FilesystemOperator;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\RequestHandlerInterface;

/**
 * Class Serve
 *
 * @package Inti\Media\Handler
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-media
 */
final class Serve implements RequestHandlerInterface
{
    /**
     * @param ServerRequestInterface $request
     * @return ResponseInterface
     */
    public function handle(ServerRequestInterface $request): ResponseInterface
    {
        /** @var FilesystemOperator $filesystem */
        $filesystem = $request->getAttribute('filesystem');
        $path = 'image://' . ltrim(rawurldecode($request->getUri()->getPath()), '/');
        $path = preg_replace('/\.[a-z0-9]{32}\./', '.', $path);

        if ($filesystem->fileExists($path)) {
            $stream = $filesystem->readStream($path);
            $mimeType = $filesystem->mimeType($path);

            return new Response($stream, 200, [
                'Content-Type' => $mimeType,
            ]);
        }

        return new Response\EmptyResponse(404);
    }
}
